@@ -10,10 +10,11 @@ import requests
 from loguru import logger
 
 from . import config
+from .evaluate import Evaluate, format_datasets_task, get_dataset_splits
 from .languages import SUPPORTED_LANGUAGES
 from .metrics import Metrics
 from .project import Project
-from .tasks import TASKS
+from .tasks import DATASETS_TASKS, TASKS
 from .utils import UnauthenticatedError, http_get, http_post
 
 
@@ -22,6 +23,7 @@ class AutoNLP:
         self.username = None
         self.token = None
         self._project = None
+        self._eval_proj = None
         self.config_dir = config_dir
         if self.config_dir is None:
             home_dir = os.path.expanduser("~")
@@ -37,9 +39,6 @@ class AutoNLP:
 
     def login(self, token: str):
         """Login to AutoNLP"""
-        if token.startswith("api_org"):
-            logger.error("⚠ Authenticating as an organization is not allowed. Please provide a user API key.")
-            raise ValueError("Login with an organization API keys are not supported")
         try:
             auth_resp = http_get(path="/whoami-v2", domain=config.HF_API, token=token, token_prefix="Bearer")
         except requests.HTTPError as err:
@@ -74,20 +73,22 @@ class AutoNLP:
                         self.orgs = conf_json["orgs"]
                         self.token = conf_json["token"]
 
-    def create_project(self, name: str, task: str, language: str):
+    def create_project(self, name: str, task: str, language: str, max_models: int):
         """Create a project and return it"""
         self._login_from_conf()
         task_id = TASKS.get(task)
+        if task_id is None:
+            raise ValueError(f"❌ Invalid task selected. Please choose one of {TASKS.keys()}")
         language = str(language).strip().lower()
         if len(language) != 2 or language not in SUPPORTED_LANGUAGES:
-            raise ValueError(f"❌ Invalid language selected. Please choose one of {SUPPORTED_LANGUAGES}")
+            raise ValueError("❌ Invalid language selected. Please check supported languages in AutoNLP documentation.")
         if task_id is None:
             raise ValueError(f"❌ Invalid task specified. Please choose one of {list(TASKS.keys())}")
         payload = {
             "username": self.username,
             "proj_name": name,
             "task": task_id,
-            "config": {"version": 0, "patch": 1, "language": language},
+            "config": {"version": 0, "patch": 1, "language": language, "max_models": max_models},
         }
         json_resp = http_post(path="/projects/create", payload=payload, token=self.token).json()
         proj_name = json_resp["proj_name"]
@@ -100,6 +101,54 @@ class AutoNLP:
         self._project.refresh()
         return self._project
 
+    def create_evaluation(
+        self, task: str, dataset: str, model: str, split: str, col_mapping: str = None, config: str = None
+    ):
+        self._login_from_conf()
+
+        splits = get_dataset_splits(dataset=dataset, config=config)
+        if split not in splits:
+            raise ValueError(f"❌ Split {split} not found in dataset {dataset}. Available splits: {splits}")
+
+        if task in DATASETS_TASKS:
+            task = format_datasets_task(task, dataset, config)
+            if col_mapping:
+                logger.warning("A task template from `datasets` has been selected. Deleting `col_mapping` ...")
+                col_mapping = None
+        elif col_mapping is None:
+            raise ValueError(
+                f"❌ A column mapping must be provided for task {task}. Please provide a value for `col_mapping`."
+            )
+
+        task_id = TASKS.get(task)
+        if task_id is None:
+            raise ValueError(f"❌ Invalid task selected. Please choose one of {TASKS.keys()}")
+
+        mapping_dict = {}
+        if col_mapping:
+            col_mapping = col_mapping.strip().split(",")
+            for c_m in col_mapping:
+                k, v = c_m.split(":")
+                mapping_dict[k] = v
+
+        payload = {
+            "username": self.username,
+            "dataset": dataset,
+            "task": task_id,
+            "model": model,
+            "col_mapping": mapping_dict,
+            "split": split,
+            "config": config,
+        }
+        json_resp = http_post(path="/evaluate/create", payload=payload, token=self.token).json()
+        self._eval_proj = Evaluate.from_json_resp(json_resp, token=self.token)
+        return self._eval_proj
+
+    def get_eval_job_status(self, eval_job_id: int) -> int:
+        self._login_from_conf()
+        json_resp = http_get(path=f"/evaluate/status/{eval_job_id}", token=self.token).json()
+        return json_resp["status"]
+
     def get_project(self, name):
         """Retrieves a project"""
         self._login_from_conf()
@@ -164,3 +213,10 @@ class AutoNLP:
         logger.info(f"📄 Retrieving projects of user {username}...")
         json_resp = http_get(path=f"/projects/list?username={username}", token=self.token).json()
         return [Project.from_json_resp(elt, token=self.token) for elt in json_resp]
+
+    def estimate(self, num_train_samples: int, proj_name: str) -> dict:
+        self._login_from_conf()
+        if self.username is None:
+            raise UnauthenticatedError("❌ Credentials not found ! Please login to AutoNLP first.")
+        project = self.get_project(name=proj_name)
+        return project.estimate_cost(num_train_samples)
