@@ -1,9 +1,9 @@
-from typing import Dict, List, Optional
+from typing import Dict, Optional
 
 import requests
-from loguru import logger
 
 from . import config
+from .tasks import TASKS
 
 
 FORMAT_TAG = "\033[{code}m"
@@ -44,12 +44,7 @@ def http_get(
         )
     except requests.exceptions.ConnectionError:
         raise UnreachableAPIError("❌ Failed to reach AutoNLP API, check your internet connection")
-    try:
-        response.raise_for_status()
-    except requests.exceptions.HTTPError as err:
-        if not suppress_logs:
-            logger.error(f"❌ Operation failed! Details: {err.response.text}")
-        raise
+    response.raise_for_status()
     return response
 
 
@@ -68,33 +63,12 @@ def http_post(
         )
     except requests.exceptions.ConnectionError:
         raise UnreachableAPIError("❌ Failed to reach AutoNLP API, check your internet connection")
-    try:
-        response.raise_for_status()
-    except requests.exceptions.HTTPError as err:
-        if not suppress_logs:
-            logger.error(f"❌ Operation failed! Details: {err.response.text}")
-        raise
+    response.raise_for_status()
     return response
 
 
-def http_upload_files(
-    path: str, token: str, data: dict, files_info: List, domain: str = config.HF_AUTONLP_BACKEND_API, **kwargs
-) -> requests.Response:
-    """Uploads files to AutoNLP"""
-    try:
-        response = requests.post(
-            url=domain + path,
-            data=data,
-            files=files_info,
-            headers=get_auth_headers(token),
-            allow_redirects=True,
-            **kwargs,
-        )
-    except requests.exceptions.ConnectionError:
-        raise UnreachableAPIError("❌ Failed to reach AutoNLP API, check your internet connection")
-    try:
-        response.raise_for_status()
-    except requests.exceptions.HTTPError as err:
-        logger.error(f"❌ Operation failed! Details: {err.response.text}")
-        raise
-    return response
+def get_task(task_id: int) -> str:
+    for key, value in TASKS.items():
+        if value == task_id:
+            return key
+    return "❌ Unsupported task! Please update autonlp"
